@@ -5,6 +5,7 @@ import socket
 import time
 import datetime
 import pytz
+import logging
 
 class RedisClientWithRetry(object):
 
@@ -32,12 +33,12 @@ def search_obj_from_array(array, fieldname, fieldvalue):
 
 class Timer(object):
 
-    def __init__(self, logger=None):
+    def __init__(self, logger=None, logger_name='timings'):
 
         self.start = time.time()
         self.end = None
         self.timings = []
-        self.logger = logger
+        self.logger = logger or logging.getLogger(logger_name)
 
     def register(self, name, info=None):
 
